//--------------------------------------------------------------------------
// 
//  File:       ConsoleShowImage.cpp
//  Part of:    
//  Author:     Tim Philip (me@TimPhilip.net)
//  Compiler:	gcc (under BeOS)
//  Purpose:    
//
//  Notice:     (c) Copyright 2000, Tim Philip
//              All Rights Reserved
//
//  Created:    02/21/00
//
//--------------------------------------------------------------------------

#include <Application.h>
#include <Window.h>
#include <View.h>
#include <Bitmap.h>
#include <TranslationKit.h>
#include <stdio.h>


//--------------------------------------------------------------------------
//	AnImage
//--------------------------------------------------------------------------

typedef struct 
{
	char	m_cpImage[MAXPATHLEN];		// we turn the filename into a path

/*
	int		m_iX;						// X position for window
	int		m_iY;						// Y position for window
	int		m_iWidth;					// Width of image
	int		m_iHeight;					// Height of image
*/
	BRect	m_rect;						// the above four measurements
	
} AnImage;


//--------------------------------------------------------------------------
//	Preview Window
//--------------------------------------------------------------------------

class PreviewWindow : public BWindow 
{
public:
	PreviewWindow(BRect frame, AnImage *pImage);

	virtual bool QuitRequested();
	virtual void FrameResized(float width, float height);
};


PreviewWindow::PreviewWindow(BRect frame, AnImage *pImage)
			: BWindow(frame, "PreviewWindow", B_TITLED_WINDOW, /*B_NOT_RESIZABLE|B_NOT_ZOOMABLE*/0) 
{
	BView *pView = new BView(Bounds(), "PreviewView", B_FOLLOW_ALL_SIDES, B_FRAME_EVENTS | B_WILL_DRAW);
	AddChild(pView);

	BBitmap *pBitmap = BTranslationUtils::GetBitmap( pImage->m_cpImage );
	if ( pBitmap != NULL )
	{
		pView->SetViewBitmap( pBitmap, pBitmap->Bounds(), pView->Bounds(), B_FOLLOW_ALL_SIDES, 0 );
		delete pBitmap;
	}

	Show();
}

void PreviewWindow::FrameResized(float width, float height)
{
	// resize the image if the user resizes the window
	ChildAt(0)->Invalidate(Bounds());
}

bool PreviewWindow::QuitRequested()
{
	// when the user closes the window, shut the app down
	be_app->PostMessage(B_QUIT_REQUESTED);
	return true;
}


//--------------------------------------------------------------------------
//	Application Class
//--------------------------------------------------------------------------

class MyApp : public BApplication
{
public:
	MyApp(AnImage *pImage);

};

MyApp::MyApp(AnImage *pImage)
		: BApplication("application/x-vnd.BeExplorer")
{
	PreviewWindow *pWnd = new PreviewWindow( pImage->m_rect, pImage );
	pWnd = pWnd;	// get rid of annoying compiler warning
}


//--------------------------------------------------------------------------
//	Synatax()
//--------------------------------------------------------------------------
void Syntax(const char *cpMe)
{
	fprintf(stderr, "Usage: %s [image] [X] [Y] [width] [height]\n", cpMe);
	exit(-1); 
}

//--------------------------------------------------------------------------
//	ParseArgs()
//--------------------------------------------------------------------------
void ParseArgs(int argc, const char **argv, AnImage *pImage)
{
	if ( argc != 6 )
		Syntax(argv[0]);
	
	strcpy(pImage->m_cpImage, argv[1]);
	// TODO:  check to see if the file exists, abort if it doesn't

	int i;
	if ( sscanf(argv[2], "%d", &i) != 1 )	Syntax(argv[0]);
	pImage->m_rect.left = i;

	if ( sscanf(argv[3], "%d", &i) != 1 )	Syntax(argv[0]);
	pImage->m_rect.top = i;

	if ( sscanf(argv[4], "%d", &i) != 1 )	Syntax(argv[0]);
	pImage->m_rect.right = pImage->m_rect.left + i;

	if ( sscanf(argv[5], "%d", &i) != 1 )	Syntax(argv[0]);
	pImage->m_rect.bottom = pImage->m_rect.top + i;
}

//--------------------------------------------------------------------------
//	main()
//--------------------------------------------------------------------------
int main(int argc, const char **argv)
{
	AnImage image;
	
	// this function won't return if the command line parameters are invalid
	ParseArgs(argc, argv, &image);
	
	MyApp *theApp = new MyApp(&image);
	theApp->Run();
	delete theApp;
	
	return 1;
}







